@@ -22,13 +22,14 @@ class TtRssServiceRoot : public ServiceRoot, public CacheForServiceRoot {
     void start(bool freshly_activated);
     void stop();
     QString code() const;
+
+    bool isSyncable() const;
     bool canBeEdited() const;
     bool canBeDeleted() const;
     bool editViaGui();
     bool deleteViaGui();
     bool supportsFeedAdding() const;
     bool supportsCategoryAdding() const;
-    QList<QAction*> serviceMenu();
 
     QString additionalTooltip() const;
 
@@ -41,17 +42,12 @@ class TtRssServiceRoot : public ServiceRoot, public CacheForServiceRoot {
     void updateTitle();
 
   public slots:
-    void addNewFeed(const QString& url = QString());
-    void addNewCategory();
+    void addNewFeed(RootItem* selected_item, const QString& url = QString());
 
   private:
     RootItem* obtainNewTreeForSyncIn() const;
-
     void loadFromDatabase();
 
-    QAction* m_actionSyncIn;
-
-    QList<QAction*> m_serviceMenu;
     TtRssNetworkFactory* m_network;
 };
 
